/*
-------------------------------------------------------------------------------
    This file is a part of the VST Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: parameter.cpp
  Author: Francois Mazen
  Date: 25/05/16 22:01
  Description: Class for parameters.
-------------------------------------------------------------------------------
*/


#include "parameter.h"

//-----------------------------------------------------------------------------
Parameter::Parameter() :
    name(""),
    randomMode(RandomMode_Uniform),
    uniformMinValue(0),
    uniformMaxValue(1),
    normalMiddleValue(0.5),
    normalStandardDeviation(0.01),
    constantValue(0)
{

}

//-----------------------------------------------------------------------------
Parameter::Parameter(const QString& name) :
    name(name),
    randomMode(RandomMode_Uniform),
    uniformMinValue(0),
    uniformMaxValue(1),
    normalMiddleValue(0.5),
    normalStandardDeviation(0.01),
    constantValue(0)
{

}

//-----------------------------------------------------------------------------
Parameter::~Parameter()
{

}

//-----------------------------------------------------------------------------
const QString& Parameter::getName() const
{
    return this->name;
}

//-----------------------------------------------------------------------------
void Parameter::setName(const QString& newName)
{
    this->name = newName;
}

//-----------------------------------------------------------------------------
float Parameter::getUniformMinValue() const
{
    return this->uniformMinValue;
}

//-----------------------------------------------------------------------------
void Parameter::setUniformMinValue(float value)
{
    this->uniformMinValue = value;
}

//-----------------------------------------------------------------------------
float Parameter::getUniformMaxValue() const
{
    return this->uniformMaxValue;
}

//-----------------------------------------------------------------------------
void Parameter::setUniformMaxValue(float value)
{
    this->uniformMaxValue = value;
}

//-----------------------------------------------------------------------------
float Parameter::getNormalMiddleValue() const
{
    return this->normalMiddleValue;
}

//-----------------------------------------------------------------------------
void Parameter::setNormalMiddleValue(float value)
{
    this->normalMiddleValue = value;
}

//-----------------------------------------------------------------------------
float Parameter::getNormalStandardDeviation() const
{
    return this->normalStandardDeviation;
}

//-----------------------------------------------------------------------------
void Parameter::setNormalStandardDeviation(float value)
{
    this->normalStandardDeviation = value;
}

//-----------------------------------------------------------------------------
float Parameter::getConstantValue() const
{
    return this->constantValue;
}

//-----------------------------------------------------------------------------
void Parameter::setConstantValue(float value)
{
    this->constantValue = value;
}

//-----------------------------------------------------------------------------
Parameter::RandomMode Parameter::getRandomMode() const
{
    return this->randomMode;
}

//-----------------------------------------------------------------------------
void Parameter::setRandomMode(Parameter::RandomMode mode)
{
    this->randomMode = mode;
}
