/*
-------------------------------------------------------------------------------
    This file is a part of the VST Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: vpgvsthost.h
  Author: Francois Mazen
  Date: 13/06/07 17:50
  Description: header file of the VpgVstHost class
-------------------------------------------------------------------------------
*/

#ifndef VPGVSTHOST_H
#define VPGVSTHOST_H

#ifdef USE_VESTIGE
    #include "vestige/vestige.h"
#else
    #include "vst2.x/aeffectx.h"
#endif

#include <stdint.h>

class QLibrary;
class QString;

//-----------------------------------------------------------------------------
// VpgVstHost
//-----------------------------------------------------------------------------

class VpgVstHost 
{

public:

    enum ERROR_CODE
    {
        ERROR_NO_ERROR = 0,
        ERROR_PLUGIN_LOAD = 1,
        ERROR_PLUGIN_MAIN = 2,
        ERROR_PLUGIN_INSTANCE = 3,
        ERROR_PLUGIN_VALID = 4
    };

    VpgVstHost();
    ~VpgVstHost();

    ERROR_CODE load(QString filename);
    void close();
    bool isVstLoaded();
    QString getLoadedFilename();

    int32_t getFxId();
    int32_t getFxVersion();
    int32_t getNumberParams();
    int32_t getNumberPrograms();
    QString getParameterName(int32_t index);
    QString getName();
    bool useChunk();

    void setParameter(long index, float value);
    void setProgram(long num);
    void setProgramName(const char* name, long index);
    int32_t getProgramChunk(void** chunk);
    int32_t getBankChunk(void** chunk);

private:  

    // Host call back, called directly by the loaded plugin.
    static intptr_t hostCallback(AEffect* effect, int32_t opcode, int32_t index, intptr_t, void * , float );

    //create a pointer for the plugin we're going to load
    AEffect* ptrPlug;
    QLibrary* library;

};

#endif //VPGVSTHOST_H
