/*
-------------------------------------------------------------------------------
    This file is a part of the VST Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: vstlistmodel.h
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: header file of the VSTListModel class
-------------------------------------------------------------------------------
*/


#ifndef VST_LIST_MODEL_H
#define VST_LIST_MODEL_H

#include <QAbstractListModel>

#include "fxheader.h"

class VSTListModel : public QAbstractListModel
{
    Q_OBJECT

public:
    VSTListModel(QWidget * parent);
    virtual ~VSTListModel();

    //Qt model functions:
    QVariant data(const QModelIndex & index, int role ) const;
    QVariant headerData(int section, Qt::Orientation orientation, int role ) const;
    int rowCount(const QModelIndex & parent = QModelIndex() ) const;

    // Data manipulation:
    void addPluginHeader(FxHeaderStruct* fxstruct);
    void clearList();
    bool areDataSaved() const;
    void setNeedSaving(bool doesNeedSaving);
    bool isListEmpty() const;
    FxHeaderStruct* getPluginHeaderAtIndex(int index) const;

    const QList<FxHeaderStruct*>& getPluginHeaders() const;
    void beginModelChangeWithoutRefresh();
    void endModelChangeWithoutRefresh();
    void addPluginHeaderWithoutRefresh(FxHeaderStruct* fxHeader);
    void clearListWithoutRefresh();

private:
    QWidget *parentWidget; //parent widget
    QList<FxHeaderStruct*> fxHeaderList;

    //are the data saved ?
    bool areDataWritten;
};



#endif //VST_LIST_MODEL_H
